<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdDrawingAnnotation</name>
    <message>
      <location filename="../../Command.cpp" line="475"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="476"/>
      <source>&amp;Annotation</source>
      <translation>註釋(&amp;A)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="477"/>
      <location filename="../../Command.cpp" line="479"/>
      <source>Inserts an Annotation view in the active drawing</source>
      <translation>於目前圖面插入註釋視圖</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingClip</name>
    <message>
      <location filename="../../Command.cpp" line="523"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="524"/>
      <source>&amp;Clip</source>
      <translation>剪下(&amp;C)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="525"/>
      <location filename="../../Command.cpp" line="527"/>
      <source>Inserts a clip group in the active drawing</source>
      <translation>於目前圖面插入剪下群組</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingDraftView</name>
    <message>
      <location filename="../../Command.cpp" line="714"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="715"/>
      <source>&amp;Draft View</source>
      <translation>底圖檢視(&amp;D)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="716"/>
      <location filename="../../Command.cpp" line="718"/>
      <source>Inserts a Draft view of the selected object(s) in the active drawing</source>
      <translation>於目前圖面中插入所選物件之底圖視圖</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location filename="../../Command.cpp" line="625"/>
      <source>File</source>
      <translation>檔案</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="626"/>
      <source>&amp;Export page...</source>
      <translation>匯出頁面(&amp;E)...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="627"/>
      <location filename="../../Command.cpp" line="629"/>
      <source>Export a page to an SVG file</source>
      <translation>匯出此頁為SVG檔</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <location filename="../../Command.cpp" line="269"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="270"/>
      <location filename="../../Command.cpp" line="271"/>
      <source>Insert new A3 landscape drawing</source>
      <translation>插入新的 A3 橫式圖紙</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewPage</name>
    <message>
      <location filename="../../Command.cpp" line="91"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="92"/>
      <location filename="../../Command.cpp" line="93"/>
      <source>Insert new drawing</source>
      <translation>插入新繪圖區</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <location filename="../../Command.cpp" line="308"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="309"/>
      <source>Insert view in drawing</source>
      <translation>於繪圖區插入視圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="310"/>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>於目前繪圖區插入新的零件視圖</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="59"/>
      <source>Open SVG...</source>
      <translation>開啟 SVG ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Open a scalable vector graphic</source>
      <translation>開啟一個可縮放的向量圖形</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpenBrowserView</name>
    <message>
      <location filename="../../Command.cpp" line="437"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="438"/>
      <source>Open &amp;browser view</source>
      <translation>開啟瀏覽模式(&amp;b)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="439"/>
      <location filename="../../Command.cpp" line="441"/>
      <source>Opens the selected page in a browser view</source>
      <translation>以瀏覽模式開啟選定頁面</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOrthoViews</name>
    <message>
      <location filename="../../Command.cpp" line="387"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="388"/>
      <source>Insert orthographic views</source>
      <translation>插入正交視圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="389"/>
      <source>Insert an orthographic projection of a part in the active drawing</source>
      <translation>插入目前圖面零件之正交投影</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingProjectShape</name>
    <message>
      <location filename="../../Command.cpp" line="678"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="679"/>
      <source>Project shape...</source>
      <translation>專案形式</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="680"/>
      <location filename="../../Command.cpp" line="681"/>
      <source>Project shape onto a user-defined plane</source>
      <translation>投影外型至用戶定義的面上</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSpreadsheetView</name>
    <message>
      <location filename="../../Command.cpp" line="745"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="746"/>
      <source>&amp;Spreadsheet View</source>
      <translation>試算表視圖(&amp;S)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="747"/>
      <location filename="../../Command.cpp" line="749"/>
      <source>Inserts a view of a selected spreadsheet in the active drawing</source>
      <translation>於使用中之工程圖內插入所選之試算表視圖</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSymbol</name>
    <message>
      <location filename="../../Command.cpp" line="568"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="569"/>
      <source>&amp;Symbol</source>
      <translation>符號(&amp;S)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="570"/>
      <location filename="../../Command.cpp" line="572"/>
      <source>Inserts a symbol from a svg file in the active drawing</source>
      <translation>於目前圖面內插入一個來自svg檔的符號</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location filename="../../DrawingView.cpp" line="209"/>
      <source>&amp;Background</source>
      <translation>背景(&amp;B)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="215"/>
      <source>&amp;Outline</source>
      <translation>大綱(&amp;O)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="221"/>
      <source>&amp;Native</source>
      <translation>原始的(&amp;N)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="225"/>
      <source>&amp;OpenGL</source>
      <translation>OpenGL(&amp;O)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="228"/>
      <source>&amp;Image</source>
      <translation>影像(&amp;I)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="232"/>
      <source>&amp;High Quality Antialiasing</source>
      <translation>高品質反鋸齒(&amp;H)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="269"/>
      <source>Open SVG File</source>
      <translation>開啟 SVG 檔</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="270"/>
      <source>Could not open file '%1'.</source>
      <translation>無法開啟檔案"%1"。</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="357"/>
      <source>&amp;Renderer</source>
      <translation>算繪(&amp;R)</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="462"/>
      <source>Export PDF</source>
      <translation>匯出 PDF</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="463"/>
      <source>PDF file</source>
      <translation>PDF 檔</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="479"/>
      <source>Page sizes</source>
      <translation>頁面尺寸</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="480"/>
      <source>A0</source>
      <translation>A0</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="482"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="484"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="486"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="488"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="490"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="573"/>
      <source>Different orientation</source>
      <translation>不同方向</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="574"/>
      <source>The printer uses a different orientation than the drawing.
Do you want to continue?</source>
      <translation>印表機與圖面使用之方向不同，您要繼續嗎？</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="581"/>
      <location filename="../../DrawingView.cpp" line="589"/>
      <source>Different paper size</source>
      <translation>紙張尺寸不同</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="582"/>
      <location filename="../../DrawingView.cpp" line="590"/>
      <source>The printer uses a different paper size than the drawing.
Do you want to continue?</source>
      <translation>印表機與圖面之紙張尺寸不同，您要繼續嗎？</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="601"/>
      <source>Opening file failed</source>
      <translation>開啟檔案失敗</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="602"/>
      <source>Can't open file '%1' for writing.</source>
      <translation>無法開啟並寫入檔案 '%1' </translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskOrthoViews</name>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="26"/>
      <source>Orthographic Projection</source>
      <translation>正交投影</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="34"/>
      <source>Projection</source>
      <translation>投影</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="45"/>
      <source>Third Angle</source>
      <translation>第三視角</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="50"/>
      <source>First Angle</source>
      <translation>第一視角</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="62"/>
      <source>View from:</source>
      <translation>檢視自：</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="76"/>
      <location filename="../../TaskOrthoViews.ui" line="747"/>
      <source>X +ve</source>
      <translation>正向X軸</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="81"/>
      <location filename="../../TaskOrthoViews.ui" line="752"/>
      <location filename="../../TaskOrthoViews.ui" line="791"/>
      <source>Y +ve</source>
      <translation>正向Y軸</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="86"/>
      <location filename="../../TaskOrthoViews.ui" line="757"/>
      <location filename="../../TaskOrthoViews.ui" line="796"/>
      <source>Z +ve</source>
      <translation>正向Z軸</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="91"/>
      <location filename="../../TaskOrthoViews.ui" line="762"/>
      <source>X -ve</source>
      <translation>負向X軸</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="96"/>
      <location filename="../../TaskOrthoViews.ui" line="767"/>
      <location filename="../../TaskOrthoViews.ui" line="801"/>
      <source>Y -ve</source>
      <translation>負向Y軸</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="101"/>
      <location filename="../../TaskOrthoViews.ui" line="772"/>
      <location filename="../../TaskOrthoViews.ui" line="806"/>
      <source>Z -ve</source>
      <translation>負向Z軸</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="109"/>
      <source>Axis aligned right:</source>
      <translation>對齊軸右側：</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="154"/>
      <source>Secondary Views</source>
      <translation>輔助視圖</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="176"/>
      <location filename="../../TaskOrthoViews.ui" line="201"/>
      <location filename="../../TaskOrthoViews.ui" line="232"/>
      <location filename="../../TaskOrthoViews.ui" line="257"/>
      <location filename="../../TaskOrthoViews.ui" line="282"/>
      <location filename="../../TaskOrthoViews.ui" line="307"/>
      <location filename="../../TaskOrthoViews.ui" line="357"/>
      <location filename="../../TaskOrthoViews.ui" line="382"/>
      <location filename="../../TaskOrthoViews.ui" line="407"/>
      <location filename="../../TaskOrthoViews.ui" line="432"/>
      <location filename="../../TaskOrthoViews.ui" line="457"/>
      <location filename="../../TaskOrthoViews.ui" line="482"/>
      <source>Right click for axonometric settings</source>
      <translation>按右鍵來進行軸測設定</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="329"/>
      <source>Primary view</source>
      <translation>主視圖</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="532"/>
      <source>General</source>
      <translation>一般</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="541"/>
      <source>Auto scale / position</source>
      <translation>自動縮放 / 定位</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="556"/>
      <source>Scale</source>
      <translation>縮放</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="588"/>
      <source>Top left x / y</source>
      <translation>左上 x / y</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="636"/>
      <source>Spacing dx / dy</source>
      <translation>間距 dx / dy</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="681"/>
      <source>Show hidden lines</source>
      <translation>顯示影藏線</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="688"/>
      <source>Show smooth lines</source>
      <translation>顯示平滑線</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="699"/>
      <source>Axonometric</source>
      <translation>軸測圖</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="707"/>
      <source>View projection</source>
      <translation>檢視專案</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="718"/>
      <source>Isometric</source>
      <translation>等角立體</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="723"/>
      <source>Dimetric</source>
      <translation>二等角立體</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="728"/>
      <source>Trimetric</source>
      <translation>不等角立體</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="736"/>
      <source> Axis aligned up</source>
      <translation>軸已對齊</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="780"/>
      <source>Axis out and right</source>
      <translation>軸向右外側</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="814"/>
      <source>Vertical tilt</source>
      <translation>垂直傾斜</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="821"/>
      <location filename="../../TaskOrthoViews.ui" line="858"/>
      <source>Flip</source>
      <translation>翻轉</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="834"/>
      <source> Scale</source>
      <translation>比例</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="848"/>
      <source> Trimetric</source>
      <translation>不等角立體</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskProjection</name>
    <message>
      <location filename="../../TaskDialog.cpp" line="48"/>
      <source>Visible sharp edges</source>
      <translation>顯示銳利邊</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="49"/>
      <source>Visible smooth edges</source>
      <translation>顯示平滑邊</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="50"/>
      <source>Visible sewn edges</source>
      <translation>可視縫合邊</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="51"/>
      <source>Visible outline edges</source>
      <translation>可視輪廓邊</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="52"/>
      <source>Visible isoparameters</source>
      <translation>可視等角參數</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="53"/>
      <source>Hidden sharp edges</source>
      <translation>隱藏銳利邊</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="54"/>
      <source>Hidden smooth edges</source>
      <translation>隱藏平滑邊</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="55"/>
      <source>Hidden sewn edges</source>
      <translation>隱藏縫合邊</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="56"/>
      <source>Hidden outline edges</source>
      <translation>隱藏輪廓邊</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="57"/>
      <source>Hidden isoparameters</source>
      <translation>隱藏等角參數</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="74"/>
      <source>Project shapes</source>
      <translation>專案形式</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="88"/>
      <source>No active document</source>
      <translation>無可用文件</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="89"/>
      <source>There is currently no active document to complete the operation</source>
      <translation>目前尚無使用中之檔案可以完成操作</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="94"/>
      <source>No active view</source>
      <translation>無使用中之視圖</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="95"/>
      <source>There is currently no active view to complete the operation</source>
      <translation>目前尚無使用中之視圖可以完成操作</translation>
    </message>
  </context>
  <context>
    <name>Drawing_NewPage</name>
    <message>
      <location filename="../../Command.cpp" line="217"/>
      <source>Landscape</source>
      <translation>橫向</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="219"/>
      <source>Portrait</source>
      <translation>縱向</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>%1%2 %3</source>
      <translation>%1%2 %3</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="228"/>
      <source>Insert new %1%2 %3 drawing</source>
      <translation>插入新的 %1%2 %3 圖面</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="235"/>
      <source>%1%2 %3 (%4)</source>
      <translation>%1%2 %3 (%4)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="241"/>
      <source>Insert new %1%2 %3 (%4) drawing</source>
      <translation>插入新的 %1%2 %3 (%4) 圖面</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="70"/>
      <location filename="../../Command.cpp" line="589"/>
      <source>Choose an SVG file to open</source>
      <translation>選擇要開啟的 SVG 檔</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="71"/>
      <location filename="../../Command.cpp" line="590"/>
      <location filename="../../Command.cpp" line="644"/>
      <source>Scalable Vector Graphic</source>
      <translation>可縮放向量圖檔</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="321"/>
      <location filename="../../Command.cpp" line="400"/>
      <location filename="../../Command.cpp" line="450"/>
      <location filename="../../Command.cpp" line="638"/>
      <location filename="../../Command.cpp" line="758"/>
      <source>Wrong selection</source>
      <translation>錯誤的選取</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="322"/>
      <source>Select a Part object.</source>
      <translation>選取零件物件。</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="330"/>
      <location filename="../../Command.cpp" line="409"/>
      <location filename="../../Command.cpp" line="490"/>
      <location filename="../../Command.cpp" line="538"/>
      <location filename="../../Command.cpp" line="583"/>
      <location filename="../../Command.cpp" line="764"/>
      <source>No page found</source>
      <translation>未發現頁面</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="331"/>
      <location filename="../../Command.cpp" line="410"/>
      <location filename="../../Command.cpp" line="491"/>
      <location filename="../../Command.cpp" line="539"/>
      <location filename="../../Command.cpp" line="584"/>
      <location filename="../../Command.cpp" line="765"/>
      <source>Create a page first.</source>
      <translation>請先建立一個頁面</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="401"/>
      <source>Select exactly one Part object.</source>
      <translation>請確實選取一個零件物件</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="451"/>
      <location filename="../../Command.cpp" line="639"/>
      <source>Select one Page object.</source>
      <translation>選取一個頁面物件。</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="645"/>
      <source>All Files</source>
      <translation>所有檔案</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="647"/>
      <source>Export page</source>
      <translation>匯出頁面</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="759"/>
      <source>Select exactly one Spreadsheet object.</source>
      <translation>請僅選擇一個試算表物件</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="46"/>
      <location filename="../../TaskOrthoViews.cpp" line="969"/>
      <source>Make axonometric...</source>
      <translation>產生軸測...</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="47"/>
      <location filename="../../TaskOrthoViews.cpp" line="970"/>
      <source>Edit axonometric settings...</source>
      <translation>編輯軸測設定</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="48"/>
      <location filename="../../TaskOrthoViews.cpp" line="971"/>
      <source>Make orthographic</source>
      <translation>建立正投影視角</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPage.cpp" line="141"/>
      <source>Show drawing</source>
      <translation>顯示圖面</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Drawing</source>
      <translation>工程圖</translation>
    </message>
  </context>
</TS>
